package lunar

  1. Overview
  2. Docs

lunar

API

Library lunar

  • Lunar Lunar is a minimal date and time library, based primarily on a proleptic Gregorian calendar, that focuses on simple operations. Its development is needs-driven, meaning that the library is open to contributions that add use cases not initially considered.