package lunar

  1. Overview
  2. Docs

v1.2.0

  • Add an optional timezone tz argument to the Zoned_datetime.from_utc function and refine doc comments. (voodoos)

v1.1.0

  • Add Duration.to_(seconds|minutes|hours) (gr-im)
  • Add an implementation for Lunar (gr-im)

v1.0.0

  • First release of lunar exposing among other things Time, Date, Datetime, Timezone, Zoned_datetime and Range (by xvw, gr-im).