package lunar

  1. Overview
  2. Docs

lunar

From a business perspective, Lunar could be described as a composable library for manipulating dates, timestamps, and ranges using a proleptic Gregorian representation.

What does Lunar offer

  • Working with Time, Date, Datetime and Zoned_datetime
  • Range over comparable elements
  • Arithmetic and truncation operations

The smallest unit of measurement in Lunar is the second, so this library is not intended for high-precision calculations (but rather serves as a foundation for describing applications centered around calendars so it also does not support negative years or leap seconds).