package lunar

  1. Overview
  2. Docs

lunar

API

Library lunar

  • Lunar Lunar is a minimal date and time library, based primarily on a proleptic Gregorian calendar, that focuses on simple operations. Its development is needs-driven, meaning that the library is open to contributions that add use cases not initially considered.

Library lunar.unix

  • Lunar_unix Helpers for using Lunar with the Unix module, including functions to calculate the offset of the current time zone (of the process running the program) and the time t.